##
##  lmtp2nntp.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2018 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         lmtp2nntp
Summary:      Mail to News Gateway
URL:          http://www.ossp.org/pkg/tool/lmtp2nntp/
Vendor:       Thomas Lotterer
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Mail
License:      GPL
Version:      1.4.1
Release:      20181229

#   list of sources
Source0:      http://www.ossp.org/pkg/tool/lmtp2nntp/lmtp2nntp-%{version}.tar.gz
Source1:      rc.lmtp2nntp
Source2:      lmtp2nntp.conf

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc
PreReq:       OpenPKG, openpkg >= 20160101

%description
    The OSSP lmtp2nntp program is an LMTP service for use in conjunction
    with an MTA (like Sendmail), providing a reliable real-time mail to news
    gateway. Input messages get their headers slightly reformatted to match
    Usenet news article format. The article is then posted or feeded into
    a remote NNTP service (like INN). Delivery must take place immediately
    or the transaction fails. OSSP lmtp2nntp relies on the queuing
    capabilities of the MTA in order to provide a fully reliable service.
    For this the program returns proper delivery status notification which
    indicates successful completed action, persistent transient failure or
    permanent failure.

%track
    prog lmtp2nntp = {
        version   = %{version}
        url       = http://www.ossp.org/pkg/tool/lmtp2nntp/
        regex     = lmtp2nntp-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    ./configure \
        --prefix=%{l_prefix}
    %{l_make} %{l_mflags}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/lmtp2nntp \
        $RPM_BUILD_ROOT%{l_prefix}/var/lmtp2nntp
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.lmtp2nntp} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE lmtp2nntp.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/lmtp2nntp/
    %{l_shtool} install -c -m 644 \
        INSTALL $RPM_BUILD_ROOT%{l_prefix}/etc/lmtp2nntp/lmtp2nntp.info
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/lmtp2nntp/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} lmtp2nntp status 2>/dev/null`
    [ ".$lmtp2nntp_active" = .yes ] && %{l_rc} lmtp2nntp restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} lmtp2nntp stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/lmtp2nntp/lmtp2nntp.log* >/dev/null 2>&1 || true
    exit 0

